@@ -2,7 +2,7 @@
 
 /* Purpose: String utilities */
 
-/* Copyright (C) 1995--2017 Charlie Zender
+/* Copyright (C) 1995--2018 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
    You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
@@ -26,8 +26,7 @@
 
 #ifdef _MSC_VER
 # define NEED_STRSEP
-//# define NEED_STRCASECMP (netcdf defines strcasecmp for MSVC)
-# define strncasecmp _strnicmp // (but not strncasecmp)
+# define NEED_STRCASECMP 
 # define NEED_STRCASESTR
 #endif /* !_MSC_VER */
 
